.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart on Thu Jun 28 12:35:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Atmospheric data Community Toolkit Documentation
================================================

.. toctree::
   :maxdepth: 4

   installation
   CREATING_ENVIRONMENTS.rst
   CONTRIBUTING.rst
   usage
   source/auto_examples/index.rst
   release-history
   API/index.rst

